==> 0.3.1%2B1.tar.gz: example/ios/Runner/BackgroundScannerResponse.swift <==
import Foundation
import CoreLocation
import snowm_scanner
import FirebaseDatabase

class BackgroundScannerResponse: SnowMBackgroundScanningServiceDelegate {

    static let shared = BackgroundScannerResponse()
    
    let notification = NotificationHelper()
    
    var database = Database.database()
    var count = 0

    func onLocationUpdated(locations: [CLLocation]) {
        sendLogToServer(message:"locationChangeDetected");
    }
    
    func onBeaconDetected(beacons: [SnowMBeacon], customData: Dictionary<String, Any>?) {
        sendLogToServer(message:"Scanned beacons")
    }
    
    
    func onRegionEntered(){
        count+=1
        notification.showNotification(message: "onRegionEntered \(count)");
        sendLogToServer(message:"onRegionEntered")
    }
    
    func onRegionExited(){
        count+=1
        sendLogToServer(message:"onRegionExited")
        notification.showNotification(message: "onRegionExited \(count)");
    }
    
    var lastMessage = "";
    func sendLogToServer(message: String){
        if(lastMessage == message) {return}
        lastMessage = message
        var data  = Dictionary<String, Any>()
        data["message"] = message
        let dateFormatterGet = DateFormatter()
           dateFormatterGet.dateFormat="yyyy-MM-dd hh:mm:ss"
           data["time"]   = dateFormatterGet.string(from: Date())
        database.reference().child("logs").childByAutoId().setValue(data);
    }
    
    
    func didEnterGeofence() {
        count+=1
        sendLogToServer(message:"didEnterGeofence")
        notification.showNotification(message: "didEnterGeofence \(count)");
    }
    
    func didExitGeofence() {
        count+=1
        sendLogToServer(message:"didExitGeofence")
        notification.showNotification(message: "didEnterGeofence \(count)");
    }
    
}

==> 0.4.0%2B1.tar.gz: example/ios/Runner/BackgroundScannerResponse.swift <==
import Foundation
import CoreLocation
import snowm_scanner
<<<<<<< HEAD

class BackgroundScannerResponse: SnowMBackgroundScanningServiceDelegate {
    static let shared = BackgroundScannerResponse()

    func onLocationUpdated(locations: [CLLocation]) {
        print("on Location change detected");
    }
    
    func onBeaconDetected(beacons: [SnowMBeacon], customData: Dictionary<String, Any>?) {
        print("onBeacon detected called from background scanner");
    }
=======
import FirebaseDatabase

class BackgroundScannerResponse: SnowMBackgroundScanningServiceDelegate {
    func onRegionEntered(uuids: [String]) {
        
    }
    
    
    static let shared = BackgroundScannerResponse()
    
    let notification = NotificationHelper()
    
    var database = Database.database()
    private static var count = 0
    
    func onLocationUpdated(locations: [CLLocation]) {
        sendLogToServer(message:"locationChangeDetected");
    }
    
    func onBeaconDetected(beacons: [SnowMBeacon], customData: Dictionary<String, Any>?) {
        sendLogToServer(message:"Scanned beacons")
    }
    
    
    func onRegionEntered(){
        BackgroundScannerResponse.count+=1
        notification.showNotification(message: "onRegionEntered \(BackgroundScannerResponse.count)");
        sendLogToServer(message:"onRegionEntered")
    }
    
    func onRegionExited(){
        BackgroundScannerResponse.count+=1
        sendLogToServer(message:"onRegionExited")
        notification.showNotification(message: "onRegionExited \(BackgroundScannerResponse.count)");
    }
    
    var lastMessage = "";
    func sendLogToServer(message: String){
        print(message)
        if(lastMessage == message) {return}
        lastMessage = message
        var data  = Dictionary<String, Any>()
        data["message"] = message
        let dateFormatterGet = DateFormatter()
        dateFormatterGet.dateFormat="yyyy-MM-dd hh:mm:ss"
        data["time"]   = dateFormatterGet.string(from: Date())
        database.reference().child("logs").childByAutoId().setValue(data);
    }
    
    
    func didEnterGeofence() {
        BackgroundScannerResponse.count+=1
        sendLogToServer(message:"didEnterGeofence")
        notification.showNotification(message: "didEnterGeofence \(BackgroundScannerResponse.count)");
    }
    
    func didExitGeofence() {
        BackgroundScannerResponse.count+=1
        sendLogToServer(message:"didExitGeofence")
        notification.showNotification(message: "didEnterGeofence \(BackgroundScannerResponse.count)");
    }
    
>>>>>>> 608f09bae49935f13a9882f589fdea820fa413dd
}
